@@ -29,7 +29,7 @@
 #include <kwindowsystem_export.h>
 #include <QWidget>
 #include <config-kwindowsystem.h>
-#if HAVE_X11
+#if KWINDOWSYSTEM_HAVE_X11
 #include <xcb/xcb.h>
 
 #include "netwm_def.h"
@@ -127,7 +127,7 @@ public:
         to the first element of the properties array in the above constructor,
         and therefore you cannot read all root window properties using it.
     **/
-    NETRootInfo(xcb_connection_t *connection, unsigned long properties, int screen = -1,
+    NETRootInfo(xcb_connection_t *connection, NET::Properties properties, int screen = -1,
                 bool doActivate = true);
 
     /**
@@ -910,7 +910,7 @@ public:
         in the above constructor.
     **/
     NETWinInfo(xcb_connection_t *connection, xcb_window_t window,
-               xcb_window_t rootWindow, unsigned long properties,
+               xcb_window_t rootWindow, NET::Properties properties,
                Role role = Client);
 
     /**
@@ -959,7 +959,7 @@ public:
 
        @return the state of the window
     **/
-    unsigned long state() const;
+    NET::States state() const;
 
     /**
        Returns the extended (partial) strut specified by this client.
@@ -988,7 +988,7 @@ public:
 
        @return the type of the window
     **/
-    WindowType windowType(unsigned long supported_types) const;
+    WindowType windowType(WindowTypes supported_types) const;
 
     /**
       This function returns false if the window has not window type
@@ -1111,7 +1111,7 @@ public:
 
        @param mask the mask for the state
     **/
-    void setState(unsigned long state, unsigned long mask);
+    void setState(NET::States state, NET::States mask);
 
     /**
        Sets the window type for this client (see the NET base class
@@ -1271,12 +1271,12 @@ public:
     /**
      * Sets actions that the window manager allows for the window.
      */
-    void setAllowedActions(unsigned long actions);
+    void setAllowedActions(NET::Actions actions);
 
     /**
      * Returns actions that the window manager allows for the window.
      */
-    unsigned long allowedActions() const;
+    NET::Actions allowedActions() const;
 
     /**
      * Returns the WM_TRANSIENT_FOR property for the window, i.e. the mainwindow
@@ -1423,7 +1423,7 @@ protected:
 
        @param mask the mask for the state
     **/
-    virtual void changeState(unsigned long state, unsigned long mask)
+    virtual void changeState(NET::States state, NET::States mask)
     {
         Q_UNUSED(state);
         Q_UNUSED(mask);
